@@ -41,7 +41,7 @@ import org.apache.commons.validator.util.ValidatorUtils;
  *
  * <strong>Note</strong>: The validation method is assumed to be thread safe.
  *
- * @version $Revision: 1713331 $
+ * @version $Revision: 1739361 $
  */
 public class ValidatorAction implements Serializable {
 
@@ -420,7 +420,7 @@ public class ValidatorAction implements Serializable {
         }
 
         StringBuilder buffer = new StringBuilder();
-        BufferedReader reader = new BufferedReader(new InputStreamReader(is));
+        BufferedReader reader = new BufferedReader(new InputStreamReader(is)); // TODO encoding
         try {
             String line = null;
             while ((line = reader.readLine()) != null) {
@@ -499,6 +499,7 @@ public class ValidatorAction implements Serializable {
      * Returns a string representation of the object.
      * @return a string representation.
      */
+    @Override
     public String toString() {
         StringBuilder results = new StringBuilder("ValidatorAction: ");
         results.append(name);
@@ -646,7 +647,7 @@ public class ValidatorAction implements Serializable {
         Class<?>[] parameterClasses = new Class[this.methodParameterList.size()];
 
         for (int i = 0; i < this.methodParameterList.size(); i++) {
-            String paramClassName = (String) this.methodParameterList.get(i);
+            String paramClassName = this.methodParameterList.get(i);
 
             try {
                 parameterClasses[i] = loader.loadClass(paramClassName);
