@@ -50,7 +50,7 @@ import org.xml.sax.Attributes;
  * release.
  * </p>
  *
- * @version $Revision: 1713452 $
+ * @version $Revision: 1739361 $
  */
 //TODO mutable non-private fields
 public class ValidatorResources implements Serializable {
@@ -89,6 +89,7 @@ public class ValidatorResources implements Serializable {
      * a <code>Locale</code> key (expressed as a String).
      * @deprecated Subclasses should use getFormSets() instead.
      */
+    @Deprecated
     protected FastHashMap hFormSets = new FastHashMap(); // <String, FormSet>
 
     /**
@@ -96,6 +97,7 @@ public class ValidatorResources implements Serializable {
      * the name of the constant as the key.
      * @deprecated Subclasses should use getConstants() instead.
      */
+    @Deprecated
     protected FastHashMap hConstants = new FastHashMap(); // <String, String>
 
     /**
@@ -103,6 +105,7 @@ public class ValidatorResources implements Serializable {
      * the name of the <code>ValidatorAction</code> as the key.
      * @deprecated Subclasses should use getActions() instead.
      */
+    @Deprecated
     protected FastHashMap hActions = new FastHashMap(); // <String, ValidatorAction>
 
     /**
@@ -284,6 +287,7 @@ public class ValidatorResources implements Serializable {
 
         // Create a new rule to process args elements
         Rule rule = new Rule() {
+            @Override
             public void begin(String namespace, String name,
                                Attributes attributes) throws Exception {
                 // Create the Arg
@@ -294,7 +298,8 @@ public class ValidatorResources implements Serializable {
                     arg.setResource(false);
                 }
                 try {
-                    arg.setPosition(Integer.parseInt(name.substring(3)));
+                    final int length = "arg".length(); // skip the arg prefix
+                    arg.setPosition(Integer.parseInt(name.substring(length)));
                 } catch (Exception ex) {
                     getLog().error("Error parsing Arg position: "
                                + name + " " + arg + " " + ex);
@@ -568,16 +573,16 @@ public class ValidatorResources implements Serializable {
         if (fs.getType() == FormSet.LANGUAGE_FORMSET) {
             parent = defaultFormSet;
         } else if (fs.getType() == FormSet.COUNTRY_FORMSET) {
-            parent = (FormSet) getFormSets().get(buildLocale(fs.getLanguage(),
+            parent = getFormSets().get(buildLocale(fs.getLanguage(),
                     null, null));
             if (parent == null) {
                 parent = defaultFormSet;
             }
         } else if (fs.getType() == FormSet.VARIANT_FORMSET) {
-            parent = (FormSet) getFormSets().get(buildLocale(fs.getLanguage(), fs
+            parent = getFormSets().get(buildLocale(fs.getLanguage(), fs
                     .getCountry(), null));
             if (parent == null) {
-                parent = (FormSet) getFormSets().get(buildLocale(fs.getLanguage(),
+                parent = getFormSets().get(buildLocale(fs.getLanguage(),
                         null, null));
                 if (parent == null) {
                     parent = defaultFormSet;
@@ -604,7 +609,7 @@ public class ValidatorResources implements Serializable {
             return defaultFormSet;
         }
 
-        return (FormSet)getFormSets().get(key);
+        return getFormSets().get(key);
     }
 
     /**
