@@ -59,7 +59,7 @@ import java.util.Locale;
  *       <li>using a specified pattern with a specified <code>Locale</code></li>
  *    </ul>
  *
- * @version $Revision: 1739356 $
+ * @version $Revision: 1782756 $
  * @since Validator 1.3.0
  */
 public class IntegerValidator extends AbstractNumberValidator {
@@ -250,6 +250,6 @@ public class IntegerValidator extends AbstractNumberValidator {
             longValue > Integer.MAX_VALUE) {
             return null;
         }
-        return new Integer((int)longValue);
+        return Integer.valueOf((int)longValue);
     }
 }
